Hi,

Well, if you see this part:

> H 3 : IT 11 : I 1 : DB : inte: CPU | desc: Linux webnetman01 2.4.20-64GB-SMP #1 SMP Tue Aug 10 10:50:22 UTC 2004 i686 | cpu_: 1
> H 3 : IT 11 : I 1 : HOST: inte: CPU | desc: Linux webnetman01 2.4.20-64GB-SMP #1 SMP Tue Aug 10 10:50:22 UTC 2004 i686 | cpu_: 1


That means SNMP works, we only get teh System description via SNMP.

So SNMP is working, you have you agent configured to filter the other parts.

Show us your

# cat /etc/snmp/snmpd.conf | egrep -v '^#'  | uniq

Javier

[EMAIL PROTECTED] wrote:
The SNMP community is correct in the hosts screen. I don't have a r/w 
community, but that shouldn't matter, right?

I ran php -q autodiscovery_interfaces.php 3 form the command line and got this:
H 3 : IT 2 : Autodiscovering TCP Ports
H 3 : IT 2 : I 22 : DB : inte: Port 22 | desc: ssh | chec: | chec: H 3 : IT 2 : I 22 : HOST: inte: Port 22 | desc: ssh | chec: | chec: H 3 : IT 2 : I 22 : RES : Nothing Done.
H 3 : IT 2 : I 111 : DB : inte: Port 111 | desc: rpcbind | chec: | chec: H 3 : IT 2 : I 111 : HOST: inte: Port 111 | desc: rpcbind | chec: | chec: H 3 : IT 2 : I 111 : RES : Nothing Done.
H 3 : IT 3 : Autodiscovering Cisco System Info
H 3 : IT 4 : Autodiscovering Physical Interfaces
H 3 : IT 6 : Autodiscovering BGP Neighbors
H 3 : IT 8 : Autodiscovering Storage
H 3 : IT 9 : Autodiscovering CSS VIPs
H 3 : IT 10 : Autodiscovering Solaris System Info
H 3 : IT 11 : Autodiscovering Linux/Unix System Info
H 3 : IT 11 : I 1 : DB : inte: CPU | desc: Linux webnetman01 2.4.20-64GB-SMP #1 SMP Tue Aug 10 10:50:22 UTC 2004 i686 | cpu_: 1
H 3 : IT 11 : I 1 : HOST: inte: CPU | desc: Linux webnetman01 2.4.20-64GB-SMP #1 SMP Tue Aug 10 10:50:22 UTC 2004 i686 | cpu_: 1
H 3 : IT 11 : I 1 : RES : Nothing Done.
H 3 : IT 12 : Autodiscovering Windows System Info
H 3 : IT 13 : Autodiscovering Cisco MAC Accounting
H 3 : IT 14 : Autodiscovering Smokeping Host
H 3 : IT 16 : Autodiscovering Cisco Power Supply
H 3 : IT 17 : Autodiscovering Cisco Temperature
H 3 : IT 18 : Autodiscovering Cisco Voltage
H 3 : IT 19 : Autodiscovering Cisco SA Agent
H 3 : IT 20 : Autodiscovering Reachable
H 3 : IT 20 : I 1 : DB : inte: Reachability Test | desc: Reachability to 10.10.17.220 | ping: 50 | thre: 70 | inte: 300
H 3 : IT 20 : I 1 : HOST: inte: Reachability Test | desc: Reachability to 10.10.17.220 | ping: | thre: | inte: H 3 : IT 20 : I 1 : RES : Nothing Done.
H 3 : IT 21 : Autodiscovering Linux Traffic Control
H 3 : IT 22 : Autodiscovering NTP
H 3 : IT 24 : Autodiscovering Compaq Physical Drives
H 3 : IT 25 : Autodiscovering Compaq Fans
H 3 : IT 26 : Autodiscovering Compaq Temperature
H 3 : IT 27 : Autodiscovering IIS Webserver Information
H 3 : IT 28 : Autodiscovering Livingston Serial Port
H 3 : IT 29 : Autodiscovering Apache Webserver Information
H 3 : Autodiscovery took 359.76 msec.


It doen't look like the php scripts are talking to snmp properly.

Is there a debug mode or log files I can look at to see what is going on?




On Sunday, January 09, 2005, at 03:57PM, Javier Szyszlican <[EMAIL PROTECTED]> wrote:


Are you completely sure the SNMP community in the Hosts screen is the correct 
one?

You could also try:

# cd /opt/jffnms/engine
# php -q autodiscovery_interfaces.php <host id>

If that works and the GUI doesn't your mod_php ( and not your php cli) is having a problem.

Javier

[EMAIL PROTECTED] wrote:

I compiled PHP --with-snmp=shared,/usr/local --with-snmp=shared as documented in the PHP docs.

In test.php, it shows this under the snmp section NET-SNMP Support enabled NET-SNMP Version 5.0.9

In setup.php everything under the Paths Configuration is OK except SMSClient and NTPQ, and under PHP Status everything is YES (including SNMP Module Loaded) except PgSQL and WDDX.

snmpwalk -v1 -c <community> <IP> returns a huge list of info - IP, ports, system, etc

Any other suggestions?



On Sunday, January 09, 2005, at 02:44PM, Javier Szyszlican <[EMAIL PROTECTED]> 
wrote:



Hi,

.1.3.6.1.4.1.2021.9 is NOT the OID for the Host-MIB Disks MIB.

Are you sure your mod_php is also configured for SNMP ?

Try /admin/adm/test.php and check if you see the SNMP module loaded.

Also, check if you see anything doing:

snmpwalk -v1 -c <community> <IP> host

Javier

[EMAIL PROTECTED] wrote:


I installed JFFNMS on Fedora Core 3 according to the documentation and the
setup.php page says everything is OK, however when I add a host and do manual
discovery, it only finds a few open ports and reachability. It is not finding
all of the snmp info. I can do a snmpwalk -v 1 <host> -c <community>
.1.3.6.1.4.1.2021.9 and it will successfully return the disk information. From
what I can gather, snmp is working properly on the server, the snmpd is
configured properly on the client. I read somewhere that you can compile php
with snmp v1 or v2c. Could this have anything to do with it?

Running:
Fedora 3
Apache 2.0.52 (compiled)
mysql-devel-3.23.58-13 (rpm)
mysql-3.23.58-13 (rpm)
mysql-server-3.23.58-13 (rpm)
PHP 4.3.9 (compiled)
NET-SNMP version: 5.0.9 (compiled)


PHP compile options: ./configure --with-pear=/usr/share/pear --with-gd --with-mysql \ --with-snmp=shared,/usr/local --with-snmp=shared --enable-sockets \ --with-pcre --with-jpeg-dir=/usr/lib --with-zlib-dir=/usr/lib \ --disable-cgi --with-apxs2=/usr/local/apache/bin/apxs \ --enable-ucd-snmp-hack

Any help would be appreciated...



-------------------------------------------------------
The SF.Net email is sponsored by: Beat the post-holiday blues
Get a FREE limited edition SourceForge.net t-shirt from ThinkGeek.
It's fun and FREE -- well, almost....http://www.thinkgeek.com/sfshirt
_______________________________________________
jffnms-users mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/jffnms-users

-- =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= Javier Szyszlican, Project Leader, JFFNMS [EMAIL PROTECTED]

I hope JFFNMS or I were helpful to you, if you
can, please donate at http://jffnms.org/donate



-------------------------------------------------------
The SF.Net email is sponsored by: Beat the post-holiday blues
Get a FREE limited edition SourceForge.net t-shirt from ThinkGeek.
It's fun and FREE -- well, almost....http://www.thinkgeek.com/sfshirt
_______________________________________________
jffnms-users mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/jffnms-users





------------------------------------------------------- The SF.Net email is sponsored by: Beat the post-holiday blues Get a FREE limited edition SourceForge.net t-shirt from ThinkGeek. It's fun and FREE -- well, almost....http://www.thinkgeek.com/sfshirt _______________________________________________ jffnms-users mailing list [email protected] https://lists.sourceforge.net/lists/listinfo/jffnms-users

-- =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= Javier Szyszlican, Project Leader, JFFNMS [EMAIL PROTECTED]

I hope JFFNMS or I were helpful to you, if you
can, please donate at http://jffnms.org/donate



-------------------------------------------------------
The SF.Net email is sponsored by: Beat the post-holiday blues
Get a FREE limited edition SourceForge.net t-shirt from ThinkGeek.
It's fun and FREE -- well, almost....http://www.thinkgeek.com/sfshirt
_______________________________________________
jffnms-users mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/jffnms-users





------------------------------------------------------- The SF.Net email is sponsored by: Beat the post-holiday blues Get a FREE limited edition SourceForge.net t-shirt from ThinkGeek. It's fun and FREE -- well, almost....http://www.thinkgeek.com/sfshirt _______________________________________________ jffnms-users mailing list [email protected] https://lists.sourceforge.net/lists/listinfo/jffnms-users

-- =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= Javier Szyszlican, Project Leader, JFFNMS [EMAIL PROTECTED]

I hope JFFNMS or I were helpful to you, if you
can, please donate at http://jffnms.org/donate



-------------------------------------------------------
The SF.Net email is sponsored by: Beat the post-holiday blues
Get a FREE limited edition SourceForge.net t-shirt from ThinkGeek.
It's fun and FREE -- well, almost....http://www.thinkgeek.com/sfshirt
_______________________________________________
jffnms-users mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/jffnms-users

Reply via email to